==> open-xchange-core_6.22.0.orig.tar.bz2: open-xchange-core-6.22.0/com.openexchange.server/src/com/openexchange/mail/api/IMailFolderStorageEnhanced.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mail.api;

import com.openexchange.exception.OXException;

/**
 * {@link IMailFolderStorageEnhanced}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public interface IMailFolderStorageEnhanced extends IMailFolderStorage {

    /**
     * Gets the number of unread mails for specified folder.
     *
     * @param fullName The folder's full name
     * @return The unread counter
     * @throws OXException If an error occurs
     */
    int getUnreadCounter(String fullName) throws OXException;

    /**
     * Gets the number of new mails for specified folder (since last access to folder).
     *
     * @param fullName The folder's full name
     * @return The new counter
     * @throws OXException If an error occurs
     */
    int getNewCounter(String fullName) throws OXException;

    /**
     * Gets the total number of mails for specified folder.
     *
     * @param fullName The folder's full name
     * @return The total counter
     * @throws OXException If an error occurs
     */
    int getTotalCounter(String fullName) throws OXException;

}

==> open-xchange-core_6.22.1.orig.tar.bz2: open-xchange-core-6.22.1/com.openexchange.server/src/com/openexchange/mail/api/IMailFolderStorageEnhanced.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mail.api;

import com.openexchange.exception.OXException;

/**
 * {@link IMailFolderStorageEnhanced}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public interface IMailFolderStorageEnhanced extends IMailFolderStorage {

    /**
     * Expunge all messages marked as \Deleted and moves them to trash folder.
     * 
     * @param fullName The folder full name
     * @throws OXException If expunge operation fails
     */
    public void expungeFolder(String fullName) throws OXException;

    /**
     * Expunge all messages marked as \Deleted.
     * 
     * @param fullName The folder full name
     * @param hardDelete <code>true</code> to perform hard-delete; otherwise messages are moved to trash folder
     * @throws OXException If expunge operation fails
     */
    public void expungeFolder(String fullName, boolean hardDelete) throws OXException;

    /**
     * Gets the number of unread mails for specified folder.
     *
     * @param fullName The folder's full name
     * @return The unread counter
     * @throws OXException If an error occurs
     */
    int getUnreadCounter(String fullName) throws OXException;

    /**
     * Gets the number of new mails for specified folder (since last access to folder).
     *
     * @param fullName The folder's full name
     * @return The new counter
     * @throws OXException If an error occurs
     */
    int getNewCounter(String fullName) throws OXException;

    /**
     * Gets the total number of mails for specified folder.
     *
     * @param fullName The folder's full name
     * @return The total counter
     * @throws OXException If an error occurs
     */
    int getTotalCounter(String fullName) throws OXException;

}
